<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="fi">
<context>
    <name>AddAppDialog</name>
    <message>
        <location filename="addappdialog.ui" line="23"/>
        <source>Dialog</source>
        <translation>Vuoropuhelu</translation>
    </message>
    <message>
        <location filename="addappdialog.ui" line="33"/>
        <source>Categories</source>
        <translation>Kategoriat</translation>
    </message>
    <message>
        <location filename="addappdialog.ui" line="45"/>
        <source>Add category</source>
        <translation>Lisää kategoria</translation>
    </message>
    <message>
        <location filename="addappdialog.ui" line="59"/>
        <source>Delete category</source>
        <translation>Poista kategoria</translation>
    </message>
    <message>
        <location filename="addappdialog.ui" line="76"/>
        <source>Command:</source>
        <translation>Komento:</translation>
    </message>
    <message>
        <location filename="addappdialog.ui" line="121"/>
        <source>Save Changes</source>
        <translation>Tallenna muutokset</translation>
    </message>
    <message>
        <location filename="addappdialog.ui" line="128"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="addappdialog.ui" line="166"/>
        <source>Quit dialog</source>
        <translation>Lopeta-ilmoite</translation>
    </message>
    <message>
        <location filename="addappdialog.ui" line="169"/>
        <location filename="addappdialog.cpp" line="103"/>
        <source>Cancel</source>
        <translation>Peruuta</translation>
    </message>
    <message>
        <location filename="addappdialog.ui" line="176"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="addappdialog.ui" line="194"/>
        <source>Select...</source>
        <translation>Valitse...</translation>
    </message>
    <message>
        <location filename="addappdialog.ui" line="201"/>
        <source>Name:</source>
        <translation>Nimi:</translation>
    </message>
    <message>
        <location filename="addappdialog.ui" line="208"/>
        <source>Comment:</source>
        <translation>Kommentti:</translation>
    </message>
    <message>
        <location filename="addappdialog.ui" line="215"/>
        <source>Icon:</source>
        <translation>Kuvake:</translation>
    </message>
    <message>
        <location filename="addappdialog.ui" line="222"/>
        <location filename="addappdialog.cpp" line="122"/>
        <source>Set icon</source>
        <translation>Valitse kuvake</translation>
    </message>
    <message>
        <location filename="addappdialog.ui" line="235"/>
        <source>Run in Terminal</source>
        <translation>Suorita päätteessä</translation>
    </message>
    <message>
        <location filename="addappdialog.ui" line="248"/>
        <source>Startup Notifier</source>
        <translation>Käynnistyksen ilmaisin</translation>
    </message>
    <message>
        <location filename="addappdialog.cpp" line="37"/>
        <source>Add Custom Application</source>
        <translation>Lisää mukautettu sovellus</translation>
    </message>
    <message>
        <location filename="addappdialog.cpp" line="54"/>
        <source>Error</source>
        <translation>Virhe</translation>
    </message>
    <message>
        <location filename="addappdialog.cpp" line="54"/>
        <source>Could not save the file</source>
        <translation>Tiedostoa ei voitu tallentaa</translation>
    </message>
    <message>
        <location filename="addappdialog.cpp" line="103"/>
        <source>Save changes?</source>
        <translation>Tallenna muutokset?</translation>
    </message>
    <message>
        <location filename="addappdialog.cpp" line="103"/>
        <source>Do you want to save your edits?</source>
        <translation>Haluatko tallentaa mukautuksesi?</translation>
    </message>
    <message>
        <location filename="addappdialog.cpp" line="103"/>
        <source>Save</source>
        <translation>Tallenna</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="mainwindow.ui" line="17"/>
        <location filename="mainwindow.cpp" line="835"/>
        <source>MX Menu Editor</source>
        <translation>MX-valikkomuokkaaja</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="33"/>
        <source>Advanced Editor</source>
        <translation>Edistynyt muokkaaja</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="54"/>
        <source>Categories and applications</source>
        <translation>Luokat ja sovellukset</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="81"/>
        <source>Add custom application</source>
        <translation>Lisää mukautettu sovellus</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="95"/>
        <source>Options</source>
        <translation>Asetukset</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="104"/>
        <source>Run in terminal</source>
        <translation>Aja päätteessä</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="114"/>
        <source>Hide</source>
        <translation>Piilota</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="124"/>
        <source>Notify startup</source>
        <translation>Ilmoituskäynnistin</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="147"/>
        <source>Quick Editor</source>
        <translation>Pikamuokkain</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="159"/>
        <source>Comment:</source>
        <translation>Kommentti:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="169"/>
        <source>Restore original item</source>
        <translation>Palauta alkuperäinen kohde</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="180"/>
        <source>Command:</source>
        <translation>Komento:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="190"/>
        <source>Select...</source>
        <translation>Valitse...</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="204"/>
        <source>Name:</source>
        <translation>Nimi:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="225"/>
        <source>Icon</source>
        <translation>Kuvake</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="265"/>
        <location filename="mainwindow.cpp" line="537"/>
        <source>Change icon</source>
        <translation>Vaihda kuvaketta</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="279"/>
        <source>Categories</source>
        <translation>Kategoriat</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="291"/>
        <source>Add</source>
        <translation>Lisää</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="305"/>
        <source>Delete</source>
        <translation>Poista</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="371"/>
        <source>Quit application</source>
        <translation>Lopeta sovellus</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="374"/>
        <source>Close</source>
        <translation>Sulje</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="381"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="422"/>
        <source>Display help</source>
        <translation>Näytä ohje</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="425"/>
        <source>Help</source>
        <translation>Ohje</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="432"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="451"/>
        <source>Save Changes</source>
        <translation>Tallenna muutokset</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="458"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="493"/>
        <source>About this application</source>
        <translation>Tietoja tästä sovelluksesta</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="496"/>
        <source>About...</source>
        <translation>Tietoja...</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="503"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="458"/>
        <source>Select executable file</source>
        <translation>Valitse suoritettava tiedosto</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="521"/>
        <source>Image Files (*.png *.jpg *.bmp *.xpm)</source>
        <translation>Kuvatiedostot (*.png *.jpg *.bmp *.xpm)</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="714"/>
        <source>Choose category</source>
        <translation>Valitse luokka</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="725"/>
        <location filename="mainwindow.cpp" line="841"/>
        <source>Cancel</source>
        <translation>Peru</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="726"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="816"/>
        <source>Error</source>
        <translation>Virhe</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="816"/>
        <source>Could not save the file</source>
        <translation>Tiedostoa ei voitu tallentaa</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="834"/>
        <source>About MX Menu Editor</source>
        <translation>Tietoja MX-valikkomuokkaajasta</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="835"/>
        <source>Version: </source>
        <translation>Versio: </translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="836"/>
        <source>Program for editing Xfce menu</source>
        <translation>Ohjelma Xfce-valikon mukautukseen</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="838"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="839"/>
        <source>License</source>
        <translation>Lisenssi</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="840"/>
        <source>Changelog</source>
        <translation>Muutosloki</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="856"/>
        <source>&amp;Close</source>
        <translation>&amp;Sulje</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="902"/>
        <source>Save changes?</source>
        <translation>Tallenna muutokset?</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="902"/>
        <source>Do you want to save your edits?</source>
        <translation>Haluatko tallentaa mukautuksesi?</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="main.cpp" line="51"/>
        <source>You must run this program as normal user.</source>
        <translation>Sinun täytyy suorittaa tämä ohjelma tavallisena käyttäjänä.</translation>
    </message>
</context>
</TS>